<?php

namespace Drupal\eqsf\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Link;

/**
 * Provides the EQSF Listing block.
 *
 * @Block(
 *   id = "eqsf_listing",
 *   admin_label = @Translation("EQSF Listing"),
 * )
 */
class EqsfListing extends BlockBase implements BlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function build() {

    $query = \Drupal::database()->select('eq_schedule', 'eqsf');
    $query->fields('eqsf', ['id', 'eid', 'eqid', 'start', 'stop', 'position']);
    $query->join('node_field_data', 'n', 'n.nid = eqsf.eid');
    $query->fields('n', ['title']);
    $query->condition('stop', strtotime('now'), '>=');
    $results = $query->execute()->fetchAll();
    $header = [
      // 'id' => t('EQSF ID'),
      'title' => t('Title'),
      'start' => t('Start Publishing to Queue'),
      'stop' => t('End Publishing to Queue'),
      'position' => t('Position'),
      'eid' => t('Edit'),
    ];
    foreach ($results as $result) {
      $title_link = Link::createFromRoute($result->title, 'entity.node.canonical', ['node' => $result->eid], ['absolute' => TRUE]);
      $edit_link = Link::createFromRoute('Edit', 'entity.node.edit_form', ['node' => $result->eid], ['absolute' => TRUE]);
      if ($result->position == '-300') {
        $position = 'top';
      }
      elseif ($result->position == '300') {
        $position = 'bottom';
      }
      else {
        $position = $result->position;
      }
      $position = 
      $rows[] = [
        $title_link,
        date('m-d-Y g:i A', $result->start),
        date('m-d-Y g:i A', $result->stop),
        $position,
        $edit_link,
      ];
    }
    return [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];
  }
}
